#    Inside The Data Tunnel - My game for PyWeek 20.
#    Copyright (C) 2015  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Modules

# Third party Python modules
import pygame

# Import own modules
from modules import helpers

pygame.init()

allowed_area = pygame.Rect( 0, 59, 1024, 650 )


LEVELS = {
	11: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 300,
		"_current_hitpoints": 300,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [25, 35],
		"_shooting_interval": 3,
		"_kill_score": 300,
		"_additional_dodging_amount": 15,
		"_ep_on_projectile_hit": 15
	},
	12: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 330,
		"_current_hitpoints": 330,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [35, 45],
		"_shooting_interval": 3,
		"_kill_score": 330,
		"_additional_dodging_amount": 17,
		"_ep_on_projectile_hit": 17
	},
	14: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 360,
		"_current_hitpoints": 360,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [45, 55],
		"_shooting_interval": 3,
		"_kill_score": 360,
		"_additional_dodging_amount": 19,
		"_ep_on_projectile_hit": 19
	},
	15: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 390,
		"_current_hitpoints": 390,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [55, 65],
		"_shooting_interval": 3,
		"_kill_score": 390,
		"_additional_dodging_amount": 21,
		"_ep_on_projectile_hit": 21
	},
	16: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 420,
		"_current_hitpoints": 420,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [65, 85],
		"_shooting_interval": 3,
		"_kill_score": 420,
		"_additional_dodging_amount": 21,
		"_ep_on_projectile_hit": 23
	},
	17: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 450,
		"_current_hitpoints": 450,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [75, 95],
		"_shooting_interval": 3,
		"_kill_score": 450,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 25
	},
	18: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 480,
		"_current_hitpoints": 480,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [85, 105],
		"_shooting_interval": 3,
		"_kill_score": 480,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 27
	},
	19: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 510,
		"_current_hitpoints": 510,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [95, 115],
		"_shooting_interval": 3,
		"_kill_score": 510,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 29
	},
	20: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 540,
		"_current_hitpoints": 540,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [105, 125],
		"_shooting_interval": 3,
		"_kill_score": 540,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 31
	},
	21: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 570,
		"_current_hitpoints": 570,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [115, 135],
		"_shooting_interval": 3,
		"_kill_score": 570,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 33
	},
	22: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 600,
		"_current_hitpoints": 600,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [125, 145],
		"_shooting_interval": 3,
		"_kill_score": 600,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 35
	},
	23: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 630,
		"_current_hitpoints": 630,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [135, 155],
		"_shooting_interval": 3,
		"_kill_score": 630,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 37
	},
	24: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 660,
		"_current_hitpoints": 660,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [145, 165],
		"_shooting_interval": 3,
		"_kill_score": 660,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 39
	},
	25: {
		"_image": "Trojan_Horse.png",
		"_direction": 90,
		"_speed": 1,
		"_turn_speed": 5,
		"_allowed_area": allowed_area,
		"_max_hitpoints": 690,
		"_current_hitpoints": 690,
		"_projectile_speed": 3,
		"_projectile_image": "Trojan_Horse_Projectile.png",
		"_projectile_damage": [155, 175],
		"_shooting_interval": 3,
		"_kill_score": 690,
		"_additional_dodging_amount": 25,
		"_ep_on_projectile_hit": 41
	}
}
