#    Inside The Data Tunnel - My game for PyWeek 20.
#    Copyright (C) 2015  Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Import modules
# Standard Python modules.
import os
import os.path

# Third party modules
import pygame

pygame.init()


# Settings for the window.
WINDOW_WIDTH = 1024
WINDOW_HEIGHT = 768
WINDOW_DIMENSIONS = ( WINDOW_WIDTH, WINDOW_HEIGHT )
WINDOW_MODES = pygame.FULLSCREEN

# Definition of how fast the game should run.
FPS = 50

# Definition of a few standard colours.
BLACK = ( 0, 0, 0 )
GREY1 = ( 25, 25, 25 )
WHITE = ( 255, 255, 255 )
YELLOW = ( 255, 255, 0 )
BLUE = ( 0, 0, 255 )
GREEN = ( 0, 255, 0 )
RED = ( 255, 0, 0 )
PURPLE = ( 255, 0, 255 )
LIGHT_PURPLE = ( 255, 100, 255 )
DARK_PURPLE = ( 100, 0, 100 )

# Definition of where graphics, sounds, ... can be found.
GFX_PATH = os.path.join( os.getcwd(), "gfx" )
SFX_PATH = os.path.join( os.getcwd(), "sfx" )
MUSIC_PATH = os.path.join( os.getcwd(), "music" )

MUSIC_FILENAME = "Data_Jungle.ogg"

# Active playing area.
ACTIVE_PLAYING_AREA = ( 0, 59, 1024, 709 )

# Font to be used throughout the game.
FONT_FILE_PATH = "Ubuntu-R.ttf"

# SQLite3 DB filename.
DB_NAME = "highscores"

# MENUES
MAIN_MENU = {
	"heading": {
		"_text": "INSIDE THE DATA TUNNEL",
		"_font_size": 40,
		"_colour": YELLOW,
		"_pos_lefttop": ( 297, 87 ),
		"_underline": False
	},
	"menu_items": {
		1: {
			"active": {
				"_text": "Play!",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 130 )
			},
			"passive": {
				"_text": "Play!",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 130 )				
			},
			"action": "pick_players",
			"index": 1
		},
		2: {
			"active": {
				"_text": "Story",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 144 )
			},
			"passive": {
				"_text": "Story",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 144 )
			},
			"action": "story",
			"index": 2
		},
		3: {
			"active": {
				"_text": "Help",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 158 )
			},
			"passive": {
				"_text": "Help",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 158 )
			},
			"action": "help",
			"index": 3
		},
		4: {
			"active": {
				"_text": "Highscores",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 172 )
			},
			"passive": {
				"_text": "Highscores",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 172 )
			},
			"action": "highscores",
			"index": 4
		},	
		5: {
			"active": {
				"_text": "Quit!",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 186 )
			},
			"passive": {
				"_text": "Quit!",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 186 )
			},
			"action": "quit",
			"index": 5
		}		
	}
}


CHOOSE_PLAYERS_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "1 Player",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 130 )
			},
			"passive": {
				"_text": "1 Player",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 130 )				
			},
			"action": "run_singleplayer_game",
			"index": 1
		},
		2: {
			"active": {
				"_text": "2 Players",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 144 )
			},
			"passive": {
				"_text": "2 Players",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 144 )				
			},
			"action": "run_multiplayer_game",
			"index": 2
		},
		3: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 158 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 158 )				
			},
			"action": "return",
			"index": 3
		}					
	}
}

HIGHSCORES_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "Single highscores",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 172 )
			},
			"passive": {
				"_text": "Single highscores",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 172 )				
			},
			"action": "singleplayer_highscores",
			"index": 1
		},
		2: {
			"active": {
				"_text": "Team highscores",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 186 )
			},
			"passive": {
				"_text": "Team highscores",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 186 )				
			},
			"action": "multiplayer_highscores",
			"index": 2
		},
		3: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 200 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 200 )				
			},
			"action": "return",
			"index": 3
		}				
	}
}

SINGLEPLAYER_HIGHSCORE_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 550, 172 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 550, 172 )				
			},
			"action": "return",
			"index": 1
		}
	}
}

MULTIPLAYER_HIGHSCORE_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 550, 186 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 550, 186 )				
			},
			"action": "return",
			"index": 1
		}
	}
}


STORY_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 144 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 144 )				
			},
			"action": "return",
			"index": 1
		}	
	}	
}

STORY_MENU_TEXT = """
Every second, lots of data arrives at your computer.  The problem with data is,
that some is good and some is bad.

While your firewall is being updated with the new firmware to take care of
malware, you are required to step in and defend  your computer from incoming
malware.  You are asked to control a nano-spaceship inside the data tunnel
through which all data comes in from the internet.  Your job is to get rid of
malware before it reaches your computer (which is the right-side of the in-game
area).

You are joined by 10 worthy allies that help you defend your computer.  And in
case of a larger attack, you may also ask your friend to help you defending your
computer.  Also, you will get an extra 10 worthy allies.

There are 25 waves (levels).  Neutral data helps you by occasionally dropping
items that help you win the attacks.  There are 5 types of malware:
Viruses, Trojan Horses, Worms, Rootkits and Backdoors.

Can you surive them all?  Are you the new "I eat malware for breakfast" hero?
"""


HELP_MENU = {
	"menu_items": {
		1: {
			"active": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 400, 158 )
			},
			"passive": {
				"_text": "Return",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 400, 158 )				
			},
			"action": "return",
			"index": 1
		}	
	}
}

HELP_MENU_PLAYER1_CONTROLS = {
	"_text": "Player 1 - Movement: Arrow keys; Shoot: R-Ctrl",
	"_font_size": 14,
	"_colour": WHITE,
	"_pos_lefttop": ( 300, 250 ),	
}

HELP_MENU_PLAYER2_CONTROLS = {
	"_text": "Player 2 - Movement: WASD keys; Shoot: L-Alt",
	"_font_size": 14,
	"_colour": WHITE,
	"_pos_lefttop": ( 300, 265 ),	
}

PAUSE_MENU = {
	"heading": {
		"_text": "GAME PAUSED.  ABORT ?",
		"_font_size": 40,
		"_colour": YELLOW,
		"_pos_lefttop": ( 297, 87 ),
		"_underline": False
	},
	"menu_items": {
		1: {
			"active": {
				"_text": "Yes",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 130 )
			},
			"passive": {
				"_text": "Yes",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 130 )				
			},
			"action": "abort_game",
			"index": 1
		},
		2: {
			"active": {
				"_text": "No",
				"_font_size": 14,
				"_colour": YELLOW,
				"_pos_lefttop": ( 300, 144 )
			},
			"passive": {
				"_text": "No",
				"_font_size": 14,
				"_colour": WHITE,
				"_pos_lefttop": ( 300, 144 )				
			},
			"action": "continue_game",
			"index": 2
		}
	}
}

# STRINGS
NEXT_LEVEL_HEADING = {
	"_text": "Level %s - Press ENTER to start!",
	"_font_size": 40,
	"_colour": WHITE,
	"_pos_lefttop": ( 250, 344 )
}

MISSION_ACCOMPLISHED = {
	"_text": "Congratulations!  Mission complete!",
	"_font_size": 40,
	"_colour": WHITE,
	"_pos_lefttop": ( 210, 344 )
}

MISSION_ACCOMPLISHED_FINAL_SCORE = {
	"_text": "Final Score: %d",
	"_font_size": 30,
	"_colour": WHITE,
	"_pos_lefttop": ( 430, 384 )
}

MISSION_FAILED = {
	"_text": "Sorry!  Mission failed!",
	"_font_size": 40,
	"_colour": WHITE,
	"_pos_lefttop": ( 340, 344 )
}

# Level indicator text for players and allied ships.
LEVEL_INDICATOR = {
	"_text": "LVL: %s",
	"_font_size": 9,
	"_colour": WHITE,
	"_pos_lefttop": ( 0, 0 ) # This will dynamically be changed.
}

CURRENT_LEVEL_TEXT = {
	"_text": "LEVEL: %d",
	"_font_size": 20,
	"_colour": WHITE,
	"_pos_lefttop": ( 0, 25 )
}

# Score indicator for either one or both players (single and multiplayer mode )
SCORE_INDICATOR = {
	"_text": "SCORE: %d",
	"_font_size": 20,
	"_colour": WHITE,
	"_pos_lefttop": ( 0, 0 )
}

ENTER_NAME_FOR_HIGHSCORE_TEXT_SINGLE = {
	"_text": "You have made it into the highscore!  Please enter your name below:",
	"_font_size": 20,
	"_colour": WHITE,
	"_pos_lefttop": ( 210, 339 )
}

ENTER_NAME_FOR_HIGHSCORE_TEXT_MULTI = {
	"_text": "You have made it into the highscore!  Please enter your teamname below:",
	"_font_size": 20,
	"_colour": WHITE,
	"_pos_lefttop": ( 190, 339 )
}

USERNAME_TEXT = {
	"_text": "",
	"_font_size": 30,
	"_colour": YELLOW,
	"_pos_lefttop": ( 190, 379 )
}

# Items configuration.
ITEM_CONFIG_OPTIONS = ( "single_health",
						"group_health",
						"auto_fire",
						"can_not_move",
						"health_distribution"
)

ITEMS_CONFIG = {
	"single_health": {
		"_image": "small_health_item.png",
		"_position_center": ( 0, 0 ), # will be set dynamically during the game.
		"_type": "single_health",
		"_time_to_live": 15
	},
	"group_health": {
		"_image": "big_health_item.png",
		"_position_center": ( 0, 0 ), # will be set dynamically during the game.
		"_type": "group_health",
		"_time_to_live": 12	
	},
	"auto_fire": {
		"_image": "auto_fire.png",
		"_position_center": ( 0, 0 ), # will be set dynamically during the game.
		"_type": "auto_fire",
		"_time_to_live": 10	
	},
	"can_not_move": {
		"_image": "can_not_move.png",
		"_position_center": ( 0, 0 ), # will be set dynamically during the game.
		"_type": "can_not_move",
		"_time_to_live": 8
	},
	"health_distribution": {
		"_image": "health_distribution.png",
		"_position_center": ( 0, 0 ), # will be set dynamically during the game.
		"_type": "health_distribution",
		"_time_to_live": 14	
	}
}
